@@ -1,6 +1,6 @@
 class BinaryAIException(Exception):
-    def __init__(self, code, msg, data, raw):
-        super().__init__()
+    def __init__(self, code, msg, data=None, raw=None):
+        super(BinaryAIException, self).__init__(code, msg, data, raw)
         self._code = code
         self._msg = msg
         self._data = data
@@ -16,4 +16,3 @@ class BinaryAIException(Exception):
 
     def __str__(self):
         return "{}: {}".format(self._code, self._msg)
-        
\ No newline at end of file
